# Rpg contribs

Contribs related to rpg mechanics, rules and roleplay. This is specifically for
systems that help create a rpg character (chargens), store their stats and rule
processing, dice rolling and roleplay facilitating.

Generic combat systems and other game-related systems that are commonly used in
rpgs but could _theoretically_ be used for other MMO-style games use the
`game_systems` folder.`
